@@ -85,7 +85,7 @@ use constant PRIVATE_DIR          => '/var/lib/samba/private/';
 use constant SAMBA_DNS_DIR        => '/var/lib/samba/bind-dns/';
 use constant SAMBA_DNS_ZONE       => SAMBA_DNS_DIR . 'named.conf';
 use constant SAMBA_DNS_POLICY     => SAMBA_DNS_DIR . 'named.conf.update';
-use constant SAMBA_DNS_KEYTAB     => PRIVATE_DIR . 'dns.keytab';
+use constant SAMBA_DNS_KEYTAB     => SAMBA_DNS_DIR . 'dns.keytab';
 use constant SECRETS_KEYTAB       => PRIVATE_DIR . 'secrets.keytab';
 use constant SAM_DB               => PRIVATE_DIR . 'sam.ldb';
 use constant SAMBA_PRIVILEGED_SOCKET => PRIVATE_DIR . '/ldap_priv';
@@ -700,6 +700,8 @@ sub _setConf
 
     $self->_setupNSSPAM();
 
+    # Apply ACLs to shares
+    $self->setACLs();
     # Remove shares
     $self->model('SambaDeletedShares')->removeDirs();
 
@@ -1808,7 +1810,7 @@ sub dumpConfig
     if (EBox::Sudo::fileTest('-d', $bindDir)) {
         # Storing all BIND DNS directory tree where DLZ and dns keytab are stored
         push (@cmds, "rm -rf $mirror");
-        push (@cmds, "mkdir -p $mirror/bid-dns");
+        push (@cmds, "mkdir -p $mirror/bind-dns");
         push (@cmds, "rsync -HAXavz $bindDir/ $mirror/bind-dns");
         push (@cmds, "tar pcjf $dir/bind-dns.tar.bz2 --hard-dereference -C $mirror bind-dns");
     }    
@@ -1931,7 +1933,7 @@ sub restoreConfig
         $self->stopService();
     }
 
-    # Remove bid-dns, private and sysvol
+    # Remove bind-dns, private and sysvol
     my $privateDir = PRIVATE_DIR;
     my $bindDir = SAMBA_DNS_DIR;
     my $sysvolDir = SYSVOL_DIR;
@@ -3104,4 +3106,110 @@ sub _cleanModulesForReprovision
     }
 }
 
+# Method: setACLs
+#
+#   Set ACLs for shares with pending changes
+#
+sub setACLs
+{
+    my ($self) = @_;
+
+    my $samba = $self;
+    my $sambaShares = $samba->model('SambaShares');
+
+    for my $id (@{$sambaShares->ids()}) {
+        my $row = $sambaShares->row($id);
+        my $enabled     = $row->valueByName('enabled');
+        my $shareName   = $row->valueByName('share');
+        my $pathType    = $row->elementByName('path');
+        my $guestAccess = $row->valueByName('guest');
+
+        unless ($enabled) {
+            next;
+        }
+
+        my $path = undef;
+        if ($pathType->selectedType() eq 'zentyal') {
+            $path = $samba->SHARES_DIR() . '/' . $pathType->value();
+        } elsif ($pathType->selectedType() eq 'system') {
+            $path = $pathType->value();
+        } else {
+            EBox::error("Unknown share type on share '$shareName'");
+        }
+        unless (defined $path) {
+            next;
+        }
+
+        my $syncShareFile = EBox::Config::conf() . "samba/sync_shares/$shareName";
+        my $syncShareFileExists = (-f $syncShareFile);
+
+        if (EBox::Sudo::fileTest('-d', $path)) {
+            next if EBox::Config::boolean('unmanaged_acls');
+            next unless $syncShareFileExists; # share permissions didn't change, nothing needs to be done for this share.
+        }
+
+        EBox::info("Starting to apply recursive ACLs to share '$shareName'...");
+
+        my @cmds = ();
+        push (@cmds, "mkdir -p '$path'");
+        push (@cmds, "setfacl -Rb '$path'"); # Clear POSIX ACLs
+        if ($guestAccess) {
+            push (@cmds, "chmod 0777 '$path'");
+            push (@cmds, "chown nobody:'domain users' '$path'");
+        } else {
+            push (@cmds, "chmod 0770 '$path'");
+            push (@cmds, "chown administrator:adm '$path'");
+        }
+        EBox::Sudo::root(@cmds);
+
+        # Posix ACL
+        my @posixACL;
+        push (@posixACL, 'u:administrator:rwx');
+        push (@posixACL, 'g:adm:rwx');
+        push (@posixACL, 'g:"domain admins":rwx');
+
+        for my $subId (@{$row->subModel('access')->ids()}) {
+            my $subRow = $row->subModel('access')->row($subId);
+            my $permissions = $subRow->elementByName('permissions');
+
+            my $userType = $subRow->elementByName('user_group');
+            my $perm;
+            if ($userType->selectedType() eq 'group') {
+                $perm = 'g:';
+            } elsif ($userType->selectedType() eq 'user') {
+                $perm = 'u:';
+            }
+            my $account = $userType->value();
+            my $qobject = shell_quote($account);
+            $perm .= $qobject . ':';
+
+            if ($permissions->value() eq 'readOnly') {
+                $perm .= 'rx';
+            } elsif ($permissions->value() eq 'readWrite') {
+                $perm .= 'rwx';
+            } elsif ($permissions->value() eq 'administrator') {
+                $perm .= 'rwx';
+            } else {
+                my $type = $permissions->value();
+                EBox::error("Unknown share permission type '$type'");
+                next;
+            }
+            push (@posixACL, $perm);
+        }
+
+        if (@posixACL) {
+            try {
+                EBox::Sudo::root('setfacl -R -m d:' . join(',d:', @posixACL) ." '$path'");
+                EBox::Sudo::root('setfacl -R -m ' . join(',', @posixACL) . " '$path'");
+            } catch {
+                my $error = shift;
+                EBox::error("Couldn't enable POSIX ACLs for $path: $error")
+            }
+        }
+
+        unlink ($syncShareFile) if $syncShareFileExists;
+        EBox::info("Recursive set of ACLs to share '$shareName' finished.");
+    }
+}
+
 1;
